@@ -11,12 +11,10 @@
 #' @param fullwidth If TRUE, fill the width of the parent div
 #' @return An actions buttons group control that can be added to a UI definition.
 #'
-#' @import shiny
+#' @importFrom shiny restoreInput
+#' @importFrom htmltools tags
 #'
 #' @export
-#'
-
-
 actionGroupButtons <- function(inputIds,
            labels,
            status = "default",
@@ -54,19 +52,20 @@ actionGroupButtons <- function(inputIds,
         arg = status,
         choices = c("default", "primary", "success", "info", "warning", "danger")
       )
-    tags$div(
+    htmltools::tags$div(
       class = div_class,
       role = "group",
       `aria-label` = "...",
       lapply(
         X = seq_along(labels),
         FUN = function(i) {
+          value <- shiny::restoreInput(id = inputIds[i], default = NULL)
           tags$div(
             class = "btn-group",
             role = "group",
-            tags$button(
+            htmltools::tags$button(
               id = inputIds[i],
-              type = "button",
+              type = "button",`data-val` = value,
               class = paste0("btn action-button btn-", status),
               labels[i]
             )
