@@ -143,19 +143,20 @@
 #' }
 #' }
 #'
-#' @import shiny
-#' @importFrom htmltools htmlDependency attachDependencies htmlEscape
+#' @importFrom shiny restoreInput
+#' @importFrom htmltools tags htmlEscape
 #'
 #' @export
-
-
 pickerInput <- function(inputId, label = NULL, choices, selected = NULL, multiple = FALSE,
                         options = NULL, choicesOpt = NULL, width = NULL, inline = FALSE) {
   choices <- choicesWithNames(choices)
+  selected <- shiny::restoreInput(id = inputId, default = selected)
   if (!is.null(options))
     names(options) <- paste("data", names(options), sep = "-")
   if (!is.null(width))
     options <- c(options, list("data-width" = width))
+  if (!is.null(width) && width %in% c("fit"))
+    width <- NULL
   options <- lapply(options, function(x) {
     if (identical(x, TRUE))
       "true"
@@ -164,25 +165,24 @@ pickerInput <- function(inputId, label = NULL, choices, selected = NULL, multipl
     else x
   })
   selectProps <- dropNulls(c(list(id = inputId, class = "selectpicker form-control"), options))
-  selectTag <- do.call(tags$select, c(selectProps, pickerOptions(choices, selected, choicesOpt)))
+  selectTag <- do.call(htmltools::tags$select, c(selectProps, pickerOptions(choices, selected, choicesOpt)))
 
   if (multiple)
     selectTag$attribs$multiple <- "multiple"
-  divClass <- "form-group"
+  divClass <- "form-group shiny-input-container"
   labelClass <- "control-label"
   if (inline) {
     divClass <- paste(divClass, "form-horizontal")
-    selectTag <- tags$div(class="col-sm-10", selectTag)
+    selectTag <- htmltools::tags$div(class="col-sm-10", selectTag)
     labelClass <- paste(labelClass, "col-sm-2")
   }
-  pickerTag <- tagList(
-    tags$div(
-      class = divClass,
-      if (!is.null(label)) tags$label(class = labelClass, `for` = inputId, label),
-      if (!is.null(label) & !inline) br(),
-      selectTag,
-      tags$script(HTML(paste0('$("#', escape_jquery(inputId), '").selectpicker();')))
-    )
+  pickerTag <- htmltools::tags$div(
+    class = divClass,
+    style = if (!is.null(width)) paste0("width: ", htmltools::validateCssUnit(width), ";"),
+    if (!is.null(label)) htmltools::tags$label(class = labelClass, `for` = inputId, label),
+    if (!is.null(label) & !inline) htmltools::tags$br(),
+    selectTag,
+    htmltools::tags$script(HTML(paste0('$("#', escape_jquery(inputId), '").selectpicker();')))
   )
   # Dep
   attachShinyWidgetsDep(pickerTag, "picker")
@@ -304,6 +304,8 @@ updatePickerInput <- function (session, inputId, label = NULL, selected = NULL,
 #' @param selected selected value if any
 #' @param choicesOpt additional option ofr choices
 #'
+#' @importFrom htmltools HTML htmlEscape tagList
+#'
 #' @noRd
 pickerOptions <- function (choices, selected = NULL, choicesOpt = NULL)
 {
@@ -328,11 +330,11 @@ pickerOptions <- function (choices, selected = NULL, choicesOpt = NULL)
         )
       )
       optionTag <- dropNulls(optionTag)
-      do.call(tags$optgroup, optionTag)
+      do.call(htmltools::tags$optgroup, optionTag)
     }
     else {
       optionTag <- list(
-        value = choice, HTML(htmltools::htmlEscape(label)),
+        value = choice, htmltools::HTML(htmltools::htmlEscape(label)),
         style = choicesOpt$style[i],
         `data-icon` = choicesOpt$icon[i],
         `data-subtext` = choicesOpt$subtext[i],
@@ -342,9 +344,9 @@ pickerOptions <- function (choices, selected = NULL, choicesOpt = NULL)
       )
       # optionTag$attribs <- c(optionTag$attribs, list(if (choice %in% selected) " selected" else ""))
       optionTag <- dropNulls(optionTag)
-      do.call(tags$option, optionTag)
+      do.call(htmltools::tags$option, optionTag)
     }
   })
-  return(tagList(html))
+  return(htmltools::tagList(html))
 }
 
